@@ -38,7 +38,7 @@ import (
 	v1 "k8s.io/api/core/v1"
 	podutil "k8s.io/kubernetes/pkg/api/v1/pod"
 	"k8s.io/kubernetes/pkg/controller/history"
-	"k8s.io/utils/pointer"
+	"k8s.io/utils/ptr"
 )
 
 // noopRecorder is an EventRecorder that does nothing. record.FakeRecorder has a fixed
@@ -788,7 +788,7 @@ func newPVC(name string) v1.PersistentVolumeClaim {
 			Name:      name,
 		},
 		Spec: v1.PersistentVolumeClaimSpec{
-			Resources: v1.ResourceRequirements{
+			Resources: v1.VolumeResourceRequirements{
 				Requests: v1.ResourceList{
 					v1.ResourceStorage: *resource.NewQuantity(1, resource.BinarySI),
 				},
@@ -797,7 +797,7 @@ func newPVC(name string) v1.PersistentVolumeClaim {
 	}
 }
 
-func newStatefulSetWithVolumes(replicas int, name string, petMounts []v1.VolumeMount, podMounts []v1.VolumeMount) *apps.StatefulSet {
+func newStatefulSetWithVolumes(replicas int32, name string, petMounts []v1.VolumeMount, podMounts []v1.VolumeMount) *apps.StatefulSet {
 	mounts := append(petMounts, podMounts...)
 	claims := []v1.PersistentVolumeClaim{}
 	for _, m := range petMounts {
@@ -845,7 +845,7 @@ func newStatefulSetWithVolumes(replicas int, name string, petMounts []v1.VolumeM
 			Selector: &metav1.LabelSelector{
 				MatchLabels: map[string]string{"foo": "bar"},
 			},
-			Replicas:             pointer.Int32(int32(replicas)),
+			Replicas:             ptr.To(replicas),
 			Template:             template,
 			VolumeClaimTemplates: claims,
 			ServiceName:          "governingsvc",
@@ -862,7 +862,7 @@ func newStatefulSetWithVolumes(replicas int, name string, petMounts []v1.VolumeM
 	}
 }
 
-func newStatefulSet(replicas int) *apps.StatefulSet {
+func newStatefulSet(replicas int32) *apps.StatefulSet {
 	petMounts := []v1.VolumeMount{
 		{Name: "datadir", MountPath: "/tmp/zookeeper"},
 	}
@@ -872,7 +872,7 @@ func newStatefulSet(replicas int) *apps.StatefulSet {
 	return newStatefulSetWithVolumes(replicas, "foo", petMounts, podMounts)
 }
 
-func newStatefulSetWithLabels(replicas int, name string, uid types.UID, labels map[string]string) *apps.StatefulSet {
+func newStatefulSetWithLabels(replicas int32, name string, uid types.UID, labels map[string]string) *apps.StatefulSet {
 	// Converting all the map-only selectors to set-based selectors.
 	var testMatchExpressions []metav1.LabelSelectorRequirement
 	for key, value := range labels {
@@ -900,7 +900,7 @@ func newStatefulSetWithLabels(replicas int, name string, uid types.UID, labels m
 				MatchLabels:      nil,
 				MatchExpressions: testMatchExpressions,
 			},
-			Replicas: pointer.Int32(int32(replicas)),
+			Replicas: ptr.To(replicas),
 			PersistentVolumeClaimRetentionPolicy: &apps.StatefulSetPersistentVolumeClaimRetentionPolicy{
 				WhenScaled:  apps.RetainPersistentVolumeClaimRetentionPolicyType,
 				WhenDeleted: apps.RetainPersistentVolumeClaimRetentionPolicyType,
@@ -933,7 +933,7 @@ func newStatefulSetWithLabels(replicas int, name string, uid types.UID, labels m
 				{
 					ObjectMeta: metav1.ObjectMeta{Namespace: "default", Name: "datadir"},
 					Spec: v1.PersistentVolumeClaimSpec{
-						Resources: v1.ResourceRequirements{
+						Resources: v1.VolumeResourceRequirements{
 							Requests: v1.ResourceList{
 								v1.ResourceStorage: *resource.NewQuantity(1, resource.BinarySI),
 							},
@@ -954,15 +954,15 @@ func TestGetStatefulSetMaxUnavailable(t *testing.T) {
 	}{
 		// it wouldn't hurt to also test 0 and 0%, even if they should have been forbidden by API validation.
 		{maxUnavailable: nil, replicaCount: 10, expectedMaxUnavailable: 1},
-		{maxUnavailable: intOrStrP(intstr.FromInt32(3)), replicaCount: 10, expectedMaxUnavailable: 3},
-		{maxUnavailable: intOrStrP(intstr.FromInt32(3)), replicaCount: 0, expectedMaxUnavailable: 3},
-		{maxUnavailable: intOrStrP(intstr.FromInt32(0)), replicaCount: 0, expectedMaxUnavailable: 1},
-		{maxUnavailable: intOrStrP(intstr.FromString("10%")), replicaCount: 25, expectedMaxUnavailable: 2},
-		{maxUnavailable: intOrStrP(intstr.FromString("100%")), replicaCount: 5, expectedMaxUnavailable: 5},
-		{maxUnavailable: intOrStrP(intstr.FromString("50%")), replicaCount: 5, expectedMaxUnavailable: 2},
-		{maxUnavailable: intOrStrP(intstr.FromString("10%")), replicaCount: 5, expectedMaxUnavailable: 1},
-		{maxUnavailable: intOrStrP(intstr.FromString("1%")), replicaCount: 0, expectedMaxUnavailable: 1},
-		{maxUnavailable: intOrStrP(intstr.FromString("0%")), replicaCount: 0, expectedMaxUnavailable: 1},
+		{maxUnavailable: ptr.To(intstr.FromInt32(3)), replicaCount: 10, expectedMaxUnavailable: 3},
+		{maxUnavailable: ptr.To(intstr.FromInt32(3)), replicaCount: 0, expectedMaxUnavailable: 3},
+		{maxUnavailable: ptr.To(intstr.FromInt32(0)), replicaCount: 0, expectedMaxUnavailable: 1},
+		{maxUnavailable: ptr.To(intstr.FromString("10%")), replicaCount: 25, expectedMaxUnavailable: 2},
+		{maxUnavailable: ptr.To(intstr.FromString("100%")), replicaCount: 5, expectedMaxUnavailable: 5},
+		{maxUnavailable: ptr.To(intstr.FromString("50%")), replicaCount: 5, expectedMaxUnavailable: 2},
+		{maxUnavailable: ptr.To(intstr.FromString("10%")), replicaCount: 5, expectedMaxUnavailable: 1},
+		{maxUnavailable: ptr.To(intstr.FromString("1%")), replicaCount: 0, expectedMaxUnavailable: 1},
+		{maxUnavailable: ptr.To(intstr.FromString("0%")), replicaCount: 0, expectedMaxUnavailable: 1},
 	}
 
 	for i, tc := range testCases {
@@ -977,7 +977,3 @@ func TestGetStatefulSetMaxUnavailable(t *testing.T) {
 		})
 	}
 }
-
-func intOrStrP(v intstr.IntOrString) *intstr.IntOrString {
-	return &v
-}
