@@ -38,12 +38,3 @@ const (
 	LimitedSwap   = "LimitedSwap"
 	UnlimitedSwap = "UnlimitedSwap"
 )
-
-// Alpha conditions managed by Kubelet that are not yet part of the API. The
-// entries here should be moved to staging/src/k8s.io.api/core/v1/types.go
-// once the feature managing the condition graduates to Beta.
-const (
-	// PodReadyToStartContainers pod sandbox is successfully configured and
-	// the pod is ready to launch containers.
-	PodReadyToStartContainers = "PodReadyToStartContainers"
-)
